@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -367,7 +367,7 @@ class UMLGraphicsView(EricGraphicsView):
             self.tr("Save Diagram"),
             "",
             self.tr(
-                "Portable Network Graphics (*.png);;" "Scalable Vector Graphics (*.svg)"
+                "Portable Network Graphics (*.png);;Scalable Vector Graphics (*.svg)"
             ),
             "",
             EricFileDialog.DontConfirmOverwrite,
@@ -383,7 +383,7 @@ class UMLGraphicsView(EricGraphicsView):
                     self,
                     self.tr("Save Diagram"),
                     self.tr(
-                        "<p>The file <b>{0}</b> already exists." " Overwrite it?</p>"
+                        "<p>The file <b>{0}</b> already exists. Overwrite it?</p>"
                     ).format(fpath),
                     icon=EricMessageBox.Warning,
                 )
