@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -441,9 +441,7 @@ class PySvnProjectHelper(VcsProjectHelper):
         )
         self.svnTagListAct.setStatusTip(self.tr("List tags of the project"))
         self.svnTagListAct.setWhatsThis(
-            self.tr(
-                """<b>List tags</b>""" """<p>This lists the tags of the project.</p>"""
-            )
+            self.tr("""<b>List tags</b><p>This lists the tags of the project.</p>""")
         )
         self.svnTagListAct.triggered.connect(self.__svnTagList)
         self.actions.append(self.svnTagListAct)
