@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2013 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -19,10 +19,11 @@ import trove_classifiers
 from PyQt6.QtCore import Qt, pyqtSlot
 from PyQt6.QtWidgets import QDialog, QDialogButtonBox, QListWidgetItem, QTreeWidgetItem
 
-from eric7 import Preferences, Utilities
+from eric7 import Preferences
 from eric7.EricWidgets import EricFileDialog
 from eric7.EricWidgets.EricApplication import ericApp
 from eric7.EricWidgets.EricPathPicker import EricPathPickerModes
+from eric7.SystemUtilities import FileSystemUtilities, OSUtilities
 
 from .AddEntryPointDialog import AddEntryPointDialog
 from .AddProjectUrlDialog import AddProjectUrlDialog
@@ -400,7 +401,9 @@ class SetupWizardDialog(QDialog, Ui_SetupWizardDialog):
             )
 
         sourceCode += "{0}packages=find_packages(".format(istring)
-        src = Utilities.fromNativeSeparators(self.sourceDirectoryPicker.text())
+        src = FileSystemUtilities.fromNativeSeparators(
+            self.sourceDirectoryPicker.text()
+        )
         excludePatterns = []
         for row in range(self.excludePatternList.count()):
             excludePatterns.append(self.excludePatternList.item(row).text())
@@ -554,7 +557,9 @@ class SetupWizardDialog(QDialog, Ui_SetupWizardDialog):
             options["python_requires"] = self.pyVersionEdit.text()
 
         findOptions = {}
-        src = Utilities.fromNativeSeparators(self.sourceDirectoryPicker.text())
+        src = FileSystemUtilities.fromNativeSeparators(
+            self.sourceDirectoryPicker.text()
+        )
         excludePatterns = []
         for row in range(self.excludePatternList.count()):
             excludePatterns.append(self.excludePatternList.item(row).text())
@@ -771,7 +776,9 @@ class SetupWizardDialog(QDialog, Ui_SetupWizardDialog):
             setuptools["py-modules"] = modulesArray
 
         findspec = tomlkit.table()
-        src = Utilities.fromNativeSeparators(self.sourceDirectoryPicker.text())
+        src = FileSystemUtilities.fromNativeSeparators(
+            self.sourceDirectoryPicker.text()
+        )
         excludePatterns = []
         for row in range(self.excludePatternList.count()):
             excludePatterns.append(self.excludePatternList.item(row).text())
@@ -862,7 +869,7 @@ class SetupWizardDialog(QDialog, Ui_SetupWizardDialog):
         @return start directory
         @rtype str
         """
-        return Preferences.getMultiProject("Workspace") or Utilities.getHomeDir()
+        return Preferences.getMultiProject("Workspace") or OSUtilities.getHomeDir()
 
     @pyqtSlot()
     def on_entryPointsList_itemSelectionChanged(self):
@@ -951,7 +958,9 @@ class SetupWizardDialog(QDialog, Ui_SetupWizardDialog):
             self.tr("Python Files (*.py)"),
         )
         for module in modulesList:
-            module = module.replace(Utilities.toNativeSeparators(startDir), "")
+            module = module.replace(
+                FileSystemUtilities.toNativeSeparators(startDir), ""
+            )
             if module.startswith(("\\", "/")):
                 module = module[1:]
             if module:
