@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -53,6 +53,7 @@ class EditorAssembly(QWidget):
         self.__layout.setContentsMargins(0, 0, 0, 0)
         self.__layout.setSpacing(1)
 
+        self.__showNavigator = Preferences.getEditor("ShowSourceNavigator")
         self.__showOutline = Preferences.getEditor("ShowSourceOutline")
 
         self.__editor = Editor(dbs, fn, vm, filetype, editor, tv)
@@ -90,8 +91,8 @@ class EditorAssembly(QWidget):
         self.__globalsBoundaries = {}
         self.__membersBoundaries = {}
 
-        self.__activateOutline(self.__showOutline)
-        self.__activateCombos(not self.__showOutline)
+        self.__activateOutline(self.__showNavigator and self.__showOutline)
+        self.__activateCombos(self.__showNavigator and not self.__showOutline)
 
         ericApp().getObject("UserInterface").preferencesChanged.connect(
             self.__preferencesChanged
@@ -120,11 +121,13 @@ class EditorAssembly(QWidget):
         """
         Private slot handling a change of preferences.
         """
+        showNavigator = Preferences.getEditor("ShowSourceNavigator")
         showOutline = Preferences.getEditor("ShowSourceOutline")
-        if showOutline != self.__showOutline:
+        if showOutline != self.__showOutline or showNavigator != self.__showNavigator:
             self.__showOutline = showOutline
-            self.__activateOutline(self.__showOutline)
-            self.__activateCombos(not self.__showOutline)
+            self.__showNavigator = showNavigator
+            self.__activateOutline(self.__showNavigator and self.__showOutline)
+            self.__activateCombos(self.__showNavigator and not self.__showOutline)
 
     #######################################################################
     ## Methods dealing with the navigation combos below
