@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -17,6 +17,7 @@ from eric7 import Globals
 from eric7.EricGui import EricPixmapCache
 from eric7.EricWidgets.EricApplication import EricApplication
 from eric7.Globals import getConfig
+from eric7.SystemUtilities import QtUtilities
 
 application = None
 
@@ -59,7 +60,7 @@ def version(appinfo):
         """\n"""
         """{description}\n"""
         """\n"""
-        """Copyright (c) 2002 - 2022 Detlev Offenbach"""
+        """Copyright (c) 2002 - 2023 Detlev Offenbach"""
         """ <detlev@die-offenbachs.de>\n"""
         """This is free software; see LICENSE.GPL3 for copying"""
         """ conditions.\n"""
@@ -160,8 +161,8 @@ def setLibraryPaths():
     Module function to set the Qt library paths correctly.
     """
     libPaths = (
-        os.path.join(Globals.getPyQt6ModulesDirectory(), "plugins"),
-        os.path.join(Globals.getPyQt6ModulesDirectory(), "Qt6", "plugins"),
+        os.path.join(QtUtilities.getPyQt6ModulesDirectory(), "plugins"),
+        os.path.join(QtUtilities.getPyQt6ModulesDirectory(), "Qt6", "plugins"),
     )
 
     libraryPaths = QApplication.libraryPaths()
