@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -217,7 +217,7 @@ class TRPreviewer(EricMainWindow):
         self.exitAct.setShortcut(QKeySequence(self.tr("Ctrl+Q", "File|Quit")))
         self.exitAct.setStatusTip(self.tr("Quit the application"))
         self.exitAct.setWhatsThis(
-            self.tr("""<b>Quit</b>""" """<p>Quit the application.</p>""")
+            self.tr("""<b>Quit</b><p>Quit the application.</p>""")
         )
         self.exitAct.triggered.connect(ericApp().closeAllWindows)
 
@@ -288,14 +288,14 @@ class TRPreviewer(EricMainWindow):
         self.closeAct.setShortcut(QKeySequence(self.tr("Ctrl+W", "File|Close")))
         self.closeAct.setStatusTip(self.tr("Close the current window"))
         self.closeAct.setWhatsThis(
-            self.tr("""<b>Close Window</b>""" """<p>Close the current window.</p>""")
+            self.tr("""<b>Close Window</b><p>Close the current window.</p>""")
         )
         self.closeAct.triggered.connect(self.preview.closeWidget)
 
         self.closeAllAct = QAction(self.tr("Clos&e All"), self)
         self.closeAllAct.setStatusTip(self.tr("Close all windows"))
         self.closeAllAct.setWhatsThis(
-            self.tr("""<b>Close All Windows</b>""" """<p>Close all windows.</p>""")
+            self.tr("""<b>Close All Windows</b><p>Close all windows.</p>""")
         )
         self.closeAllAct.triggered.connect(self.preview.closeAllWidgets)
 
@@ -687,7 +687,7 @@ class TranslationsDict(QObject):
             self.parent(),
             self.tr("Load Translator"),
             self.tr(
-                """<p>The translation file <b>{0}</b> could""" """ not be loaded.</p>"""
+                """<p>The translation file <b>{0}</b> could not be loaded.</p>"""
             ).format(transFileName),
         )
         return None
