@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -162,15 +162,6 @@ _getnext = re.compile(
 
 _commentsub = re.compile(r"""#[^\n]*\n|#[^\n]*$""").sub
 
-_modules = {}  # cache of modules we've seen
-
-
-def clearModulesCache():
-    """
-    Function to clear the cached modules.
-    """
-    _modules.clear()
-
 
 class VisibilityMixin(ClbrBaseClasses.ClbrVisibilityMixinBase):
     """
@@ -275,12 +266,6 @@ def readmodule_ex(module, path=None, isTypeFile=False):
     @return the resulting dictionary
     @rtype dict
     """
-    global _modules
-
-    if module in _modules:
-        # we've seen this file before...
-        return _modules[module]
-
     # search the path for the file
     f = None
     fullpath = [] if path is None else path[:]
@@ -289,18 +274,15 @@ def readmodule_ex(module, path=None, isTypeFile=False):
         f.close()
     if type not in SUPPORTED_TYPES:
         # not Ruby source, can't do anything with this module
-        _modules[module] = {}
         return {}
 
     try:
         src = Utilities.readEncodedFile(file)[0]
     except (UnicodeError, OSError):
         # can't do anything with this module
-        _modules[module] = {}
         return {}
 
-    _modules[module] = scan(src, file, module)
-    return _modules[module]
+    return scan(src, file, module)
 
 
 def scan(src, file, module):
