@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -342,10 +342,11 @@ class VcsProjectHelper(QObject):
                             self.project.ppath = projectdir
                             self.project.opened = True
 
-                            dlg = PropertiesDialog(self.project, False)
+                            dlg = PropertiesDialog(self.project, new=False)
                             if dlg.exec() == QDialog.DialogCode.Accepted:
                                 dlg.storeData()
-                                self.project.initFileTypes()
+                                if not self.project.getProjectData(dataKey="FILETYPES"):
+                                    self.project.initFileTypes()
                                 self.project.setProjectData(
                                     selectedVcsSystem, dataKey="VCS"
                                 )
