@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2022 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 
@@ -28,23 +28,16 @@ from PyQt6.QtCore import (
     pyqtSignal,
     pyqtSlot,
 )
-from PyQt6.QtGui import (
-    QClipboard,
-    QContextMenuEvent,
-    QCursor,
-    QDesktopServices,
-    QIcon,
-    QPixmap,
-)
+from PyQt6.QtGui import QClipboard, QCursor, QDesktopServices, QIcon, QPixmap
 from PyQt6.QtWebEngineCore import QWebEngineDownloadRequest, QWebEnginePage
 from PyQt6.QtWebEngineWidgets import QWebEngineView
 from PyQt6.QtWidgets import QApplication, QDialog, QMenu, QStyle
 
-from eric7 import Preferences, Utilities
+from eric7 import Preferences
 from eric7.EricGui import EricPixmapCache
 from eric7.EricWidgets import EricFileDialog, EricMessageBox
 from eric7.EricWidgets.EricApplication import ericApp
-from eric7.Globals import qVersionTuple
+from eric7.SystemUtilities import FileSystemUtilities, OSUtilities, QtUtilities
 from eric7.WebBrowser.WebBrowserWindow import WebBrowserWindow
 from eric7.WebBrowser.ZoomManager import ZoomManager
 
@@ -141,6 +134,9 @@ class WebBrowserView(QWebEngineView):
         self.__currentZoom = 100
         self.__zoomLevels = WebBrowserView.ZoomLevels[:]
 
+        self.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
+        self.customContextMenuRequested.connect(self.__showContextMenu)
+
         self.iconUrlChanged.connect(self.__iconUrlChanged)
         self.urlChanged.connect(self.__urlChanged)
         self.page().linkHovered.connect(self.__linkHovered)
@@ -182,7 +178,9 @@ class WebBrowserView(QWebEngineView):
         self.__page.safeBrowsingAbort.connect(self.safeBrowsingAbort)
         self.__page.safeBrowsingBad.connect(self.safeBrowsingBad)
         self.__page.printPageRequested.connect(self.__printPage)
-        self.__page.quotaRequested.connect(self.__quotaRequested)
+        with contextlib.suppress(AttributeError):
+            # deprecated with Qt 6.5+
+            self.__page.quotaRequested.connect(self.__quotaRequested)
         with contextlib.suppress(AttributeError):
             # Qt 6.4+
             self.__page.fileSystemAccessRequested.connect(
@@ -268,9 +266,10 @@ class WebBrowserView(QWebEngineView):
             if not os.path.exists(name.toString()):
                 name.setScheme(Preferences.getWebBrowser("DefaultScheme"))
             else:
-                if Utilities.isWindowsPlatform():
+                if OSUtilities.isWindowsPlatform():
                     name.setUrl(
-                        "file:///" + Utilities.fromNativeSeparators(name.toString())
+                        "file:///"
+                        + FileSystemUtilities.fromNativeSeparators(name.toString())
                     )
                 else:
                     name.setUrl("file://" + name.toString())
@@ -556,33 +555,17 @@ class WebBrowserView(QWebEngineView):
             )
         )
 
-    def contextMenuEvent(self, evt):
+    @pyqtSlot(QPoint)
+    def __showContextMenu(self, pos):
         """
-        Protected method called to create a context menu.
+        Private slot to show a context menu.
 
-        This method is overridden from QWebEngineView.
-
-        @param evt reference to the context menu event object
-            (QContextMenuEvent)
-        """
-        pos = evt.pos()
-        reason = evt.reason()
-        QTimer.singleShot(
-            0, functools.partial(self._contextMenuEvent, QContextMenuEvent(reason, pos))
-        )
-        # needs to be done this way because contextMenuEvent is blocking
-        # the main loop
-
-    def _contextMenuEvent(self, evt):
-        """
-        Protected method called to create a context menu.
-
-        @param evt reference to the context menu event object
-            (QContextMenuEvent)
+        @param pos position for the context menu
+        @type QPoint
         """
         self.__menu.clear()
 
-        hitTest = self.page().hitTestContent(evt.pos())
+        hitTest = self.page().hitTestContent(pos)
 
         self.__createContextMenu(self.__menu, hitTest)
 
@@ -598,8 +581,7 @@ class WebBrowserView(QWebEngineView):
         )
 
         if not self.__menu.isEmpty():
-            pos = evt.globalPos()
-            self.__menu.popup(QPoint(pos.x(), pos.y() + 1))
+            self.__menu.popup(self.mapToGlobal(pos))
 
     def __createContextMenu(self, menu, hitTest):
         """
@@ -1817,14 +1799,14 @@ class WebBrowserView(QWebEngineView):
             status
             == QWebEnginePage.RenderProcessTerminationStatus.CrashedTerminationStatus
         ):
-            msg = self.tr("The render process crashed while" " loading this page.")
+            msg = self.tr("The render process crashed while loading this page.")
         elif (
             status
             == QWebEnginePage.RenderProcessTerminationStatus.KilledTerminationStatus
         ):
             msg = self.tr("The render process was killed.")
         else:
-            msg = self.tr("The render process terminated while" " loading this page.")
+            msg = self.tr("The render process terminated while loading this page.")
         html = html.replace("@LI-1@", msg)
         html = html.replace(
             "@LI-2@",
@@ -1967,7 +1949,7 @@ class WebBrowserView(QWebEngineView):
             defaultFileName = os.path.join(documentLocation, self.url().fileName())
         else:
             defaultFileName = os.path.join(documentLocation, self.page().title())
-            if Utilities.isWindowsPlatform():
+            if OSUtilities.isWindowsPlatform():
                 defaultFileName += ".mht"
             else:
                 defaultFileName += ".mhtml"
@@ -1994,7 +1976,7 @@ class WebBrowserView(QWebEngineView):
             extension = os.path.splitext(fileName)[1]
             if not extension:
                 # add the platform specific default extension
-                if Utilities.isWindowsPlatform():
+                if OSUtilities.isWindowsPlatform():
                     extensionsIndex = 1
                 else:
                     extensionsIndex = 0
@@ -2302,6 +2284,7 @@ class WebBrowserView(QWebEngineView):
     ## Methods below implement slots for Qt 5.11+
     ###########################################################################
 
+    # deprecated with Qt 6.5+
     @pyqtSlot("QWebEngineQuotaRequest")
     def __quotaRequested(self, quotaRequest):
         """
@@ -2375,7 +2358,7 @@ class WebBrowserView(QWebEngineView):
     ## Methods below implement slots for Qt 6.4+
     ###########################################################################
 
-    if qVersionTuple() >= (6, 4, 0):
+    if QtUtilities.qVersionTuple() >= (6, 4, 0):
 
         @pyqtSlot("QWebEngineFileSystemAccessRequest")
         def __fileSystemAccessRequested(self, accessRequest):
